pub struct Options<'a, 'b> { /* private fields */ }Expand description
Exporting options.
This struct can be used to adjust the exporting process.
Examples
The following code makes the exporting process filter domains to only these explicitly mentioned. Additionally it supports multiple certificates for the same e-mail address:
use wkd_exporter::{Options, Variant};
let only_arch = Options::default()
.set_allowed_domains(vec!["archlinux.org"])
.set_variant(Variant::Advanced)
.set_append(true);Implementations
Sourceimpl<'a, 'b> Options<'a, 'b>where
'b: 'a,
impl<'a, 'b> Options<'a, 'b>where
'b: 'a,
Sourcepub fn set_allowed_domains(
self,
allowed_domains: impl Into<Option<Vec<&'a str>>>,
) -> Self
pub fn set_allowed_domains( self, allowed_domains: impl Into<Option<Vec<&'a str>>>, ) -> Self
Sets a list of allowed domains for the export.
Setting this option to None (the default) exports all domains.
Examples
The following code makes the exporting process filter domains to only these explicitly mentioned:
use wkd_exporter::Options;
let only_arch = Options::default().set_allowed_domains(vec!["archlinux.org"]);Sourcepub fn is_domain_allowed(&self, domain: &str) -> bool
pub fn is_domain_allowed(&self, domain: &str) -> bool
Check if a given domain is allowed for export.
Sourcepub fn set_variant(self, variant: Variant<'b>) -> Self
pub fn set_variant(self, variant: Variant<'b>) -> Self
Set WKD directory variant.
Setting a direct variant implies that the filter for that one
domain will be applied as well. There is no need to use
Self::set_allowed_domains when using Variant::Direct.
Examples
For small, single domain deployments, direct WKD variant may be more appropriate than the default:
use wkd_exporter::{Options, Variant};
let direct = Options::default().set_variant(Variant::Direct("metacode.biz"));Sourcepub fn set_append(self, append: bool) -> Self
pub fn set_append(self, append: bool) -> Self
Enables or disables append mode.
When appending is enabled the export will not clear target files but will rather concatenate incoming certificates to the ones existing in target directory.
This could be used to emit multiple certificates for one e-mail address which is useful for certificate rotation or storing code-signing certificates along the regular ones.
Examples
Enables append-mode which creates multiple certificates for one e-mail address:
use wkd_exporter::Options;
let append = Options::default().set_append(true);Trait Implementations